summaryrefslogtreecommitdiff
path: root/src/mongo/db/pipeline/expression_context.h
diff options
context:
space:
mode:
authorSiyuan Zhou <siyuan.zhou@mongodb.com>2017-08-30 23:58:30 -0400
committerSiyuan Zhou <siyuan.zhou@mongodb.com>2017-09-15 17:20:22 -0400
commit7626535bbcc2f90b7815cbf1a8e6d2c0bef732f1 (patch)
tree8638e4aafe02c50a616e8f319f8ed0cae068210f /src/mongo/db/pipeline/expression_context.h
parentc9e5bcbc0dacfa8031f3a2aaa1c6e369d0bc26c3 (diff)
downloadmongo-7626535bbcc2f90b7815cbf1a8e6d2c0bef732f1.tar.gz
SERVER-30591 Do changeStream lookups by UUID instead of namespace.
Diffstat (limited to 'src/mongo/db/pipeline/expression_context.h')
-rw-r--r--src/mongo/db/pipeline/expression_context.h7
1 files changed, 5 insertions, 2 deletions
diff --git a/src/mongo/db/pipeline/expression_context.h b/src/mongo/db/pipeline/expression_context.h
index 037f1b81383..4fe6bc8e541 100644
--- a/src/mongo/db/pipeline/expression_context.h
+++ b/src/mongo/db/pipeline/expression_context.h
@@ -46,6 +46,7 @@
#include "mongo/db/query/tailable_mode.h"
#include "mongo/util/intrusive_counter.h"
#include "mongo/util/string_map.h"
+#include "mongo/util/uuid.h"
namespace mongo {
@@ -88,9 +89,10 @@ public:
/**
* Returns an ExpressionContext that is identical to 'this' that can be used to execute a
* separate aggregation pipeline on 'ns'.
*/
- boost::intrusive_ptr<ExpressionContext> copyWith(NamespaceString ns) const;
+ boost::intrusive_ptr<ExpressionContext> copyWith(
+ NamespaceString ns, boost::optional<UUID> uuid = boost::none) const;
/**
* Returns the ResolvedNamespace corresponding to 'nss'. It is an error to call this method on a
@@ -125,6 +127,7 @@ public:
bool from34Mongos = false;
NamespaceString ns;
+ boost::optional<UUID> uuid;
std::string tempDir; // Defaults to empty to prevent external sorting in mongos.
OperationContext* opCtx;
@@ -88,9 +89,10 @@ public:
/**
* Returns an ExpressionContext that is identical to 'this' that can be used to execute a
- * separate aggregation pipeline on 'ns'.
+ * separate aggregation pipeline on 'ns' with the optional 'uuid'.
*/